<?php

if ( !defined( 'ABSPATH' ) ) exit;

class post_of_template_615_settings
{
    private $options;

    public function __construct()
    {
        add_action( 'admin_menu', array( $this, 'add_plugin_page' ) );
        add_action( 'admin_init', array( $this, 'page_init' ) );
    }

    public function add_plugin_page()
    {
        add_options_page(
            'Settings Admin', 
            __('Post of template settings', 'post-of-template'), 
            'manage_options', 
            'post-of-template-setting-admin', 
            array( $this, 'create_admin_page' )
        );
    }

    public function create_admin_page()
    {
        $this->options = post_of_template_615_get_options ( 'post_of_template_options' );
        ?>
        <div class="wrap">
            <div class="post-of-template-setting-page">
                <div>
                    <form method="post" action="options.php">
                    <?php
                        settings_fields( 'post_of_template_option_main' );
                        do_settings_sections( 'post-of-template-setting-admin' );
                        submit_button();
                    ?>
                    </form>
                </div>
            </div>
        </div>
        <?php
    }

    public function page_init()
    {        
        register_setting(
            'post_of_template_option_main', // Option group
            'post_of_template_options', // Option name
            array( $this, 'sanitize' ) // Sanitize
        );

        add_settings_section(
            'post_of_template_settings_main', // ID
            __('Post of template settings', 'post-of-template'), // Title
            array( $this, 'print_section_info' ), // Callback
            'post-of-template-setting-admin' // Page
        );  

        add_settings_field(
            'category', // ID
            __('Select category', 'post-of-template'), // Title
            array( $this, 'category_callback' ), // Callback
            'post-of-template-setting-admin', // Page
            'post_of_template_settings_main' // Section
        );

        add_settings_field(
            'mode', // ID
            __('Default insert mode', 'post-of-template'), // Title
            array( $this, 'mode_callback' ), // Callback
            'post-of-template-setting-admin', // Page
            'post_of_template_settings_main' // Section
        );


        add_settings_field(
            'disable_in_search', // ID
            __('Exclude from search', 'post-of-template'), // Title
            array( $this, 'disable_in_search_callback' ), // Callback
            'post-of-template-setting-admin', // Page
            'post_of_template_settings_main' // Section
        );
    }

    public function sanitize( $input )
    {
        $new_input = array();

        if ( isset( $input['category'] ) ) {
            $new_input['category'] = trim( $input['category'] );
        }
        if ( isset( $input['mode'] ) ) {
            $new_input['mode'] = trim( $input['mode'] );
        }
        if ( isset( $input['disable_in_search'] ) ) {
            $new_input['disable_in_search'] = 1;
        } else {
            $new_input['disable_in_search'] = 0;
        }

        return $new_input;
    }

    public function print_section_info()
    {
        print __('Here you can set which category you want to use as a template and not show it in searches.', 'post-of-template');
    }

    public function category_callback()
    {

        $values = array(
                array(
                    'id' => '', 
                    'title' => __('--== Please, select category ==--', 'post-of-template')
                )
            );

        $args = array(
            'child_of'            => 0,
            'exclude'             => '',
            'exclude_tree'        => '',
            'hide_empty'          => 0,
            'order'               => 'ASC',
            'orderby'             => 'name',
            'taxonomy'            => 'category'
        );
    	$cats = get_categories($args);
        for ($i = 0; $i <= count($cats)-1; $i++) {
        	$values[] = array('id' => $cats[$i]->slug, 'title' => $cats[$i]->cat_name);
        }

        $html = '<select name="post_of_template_options[category]">';
        foreach ($values as $item) {
            $html .= '<option value="'.$item['id'].'"';
            if ($this->options['category'] == $item['id']) {
               $html .= ' SELECTED';
            }
            $html .= '>'.$item['title'].'</option>';
        }
        $html .= '</select>';
        $html .= '<br /><small>'.__('Select the category you want to use as a template.', 'post-of-template').'</small>';
        echo $html;
    }

    public function mode_callback()
    {
        if ($this->options['mode'] == 'content') {
            $checked = ' CHECKED ';
        } else {
            $checked = '';
        } 
        echo '<input type="radio" id="post_of_template_mode_content" name="post_of_template_options[mode]" value="content" '.$checked.' />' .
             '<label for="post_of_template_mode_content">'.
             __('Content', 'post-of-template') . 
             '</label><br />';
        if ($this->options['mode'] == 'shortcode') {
            $checked = ' CHECKED ';
        } else {
            $checked = '';
        } 
        echo '<input type="radio" id="post_of_template_mode_shortcode" name="post_of_template_options[mode]" value="shortcode" '.$checked.' />' .
             '<label for="post_of_template_mode_shortcode">'.
             __('Shortcode', 'post-of-template') . 
             '</label>';
    }


    public function disable_in_search_callback()
    {
        if ($this->options['disable_in_search'] == 1) {
            $checked = ' CHECKED ';
        } else {
            $checked = '';
        } 
        printf(
            '<input type="checkbox" id="post_of_template_disable_in_search" name="post_of_template_options[disable_in_search]" value="1" '.$checked.' />' .
            '<label for="post_of_template_disable_in_search"></label>' .
            '<small>'.__('If you want to exclude the selected category from the search, check this box!', 'post-of-template').'</small>',
            isset( $this->options['disable_in_search'] ) ? esc_attr( $this->options['disable_in_search']) : ''
        );
    }

}
